Index: lib/src/backend/invoker.dart |
diff --git a/lib/src/backend/invoker.dart b/lib/src/backend/invoker.dart |
index 9d92eb14ca1f8fb2a4b6214c48fae3351dfb7cd5..f68172033f68dbe1db31d5483a4f9f2cba1a7846 100644 |
--- a/lib/src/backend/invoker.dart |
+++ b/lib/src/backend/invoker.dart |
@@ -234,8 +234,8 @@ class Invoker { |
void _handleError(error, [StackTrace stackTrace]) { |
if (stackTrace == null) stackTrace = new Chain.current(); |
- var afterSuccess = liveTest.isComplete && |
- liveTest.state.result == Result.success; |
+ // Store this here because it'll change when we set the state below. |
+ var shouldBeDone = liveTest.state.shouldBeDone; |
if (error is! TestFailure) { |
_controller.setState(const State(Status.complete, Result.error)); |
@@ -246,9 +246,9 @@ class Invoker { |
_controller.addError(error, stackTrace); |
removeAllOutstandingCallbacks(); |
// If a test was marked as success but then had an error, that indicates |
// that it was poorly-written and could be flaky. |
- if (!afterSuccess) return; |
+ if (!shouldBeDone) return; |
// However, users don't think of load tests as "tests", so the error isn't |
// helpful for them. |
@@ -246,9 +246,9 @@ class Invoker { |
_controller.addError(error, stackTrace); |
removeAllOutstandingCallbacks(); |
- // If a test was marked as success but then had an error, that indicates |
+ // If a test was supposed to be done but then had an error, that indicates |
// that it was poorly-written and could be flaky. |